﻿using ProjectRepairWork.Repositories;
using ProjectRepairWork.Entities;
using ProjectRepairWork.Repositories.Implementation;
using ProjectRepairWork.Entities.Enums;
using System.Diagnostics.Contracts;

namespace ProjectRepairWork.Forms
{
    public partial class FormContractor : Form
    {
        private readonly IContractorsRepository _contractorsRepository;
        private int? _contractorsId;

        public int Id
        {
            set
            {
                try
                {
                    var contractors = _contractorsRepository.ReadContractorsById(value);
                    if (contractors == null)
                    {
                        throw new InvalidDataException(nameof(contractors));
                    }
                    textBoxCompanyName.Text = contractors.CompanyName;
                    textBoxContacts.Text = contractors.Contacts;
                    _contractorsId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormContractor(IContractorsRepository contractorsRepository)
        {
            InitializeComponent();
            _contractorsRepository = contractorsRepository ?? throw new ArgumentNullException(nameof(contractorsRepository));
        }
        private void Cancel_Click(object sender, EventArgs e) => Close();
        private Contractors CreateContractors(int id) => Contractors.CreatEntity(
       id,
       textBoxCompanyName.Text,
       textBoxContacts.Text);

        private void Save_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxCompanyName.Text) ||
                    string.IsNullOrWhiteSpace(textBoxContacts.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_contractorsId.HasValue)
                {
                    _contractorsRepository.UpdateContractors(CreateContractors(_contractorsId.Value));
                }
                else
                {
                    _contractorsRepository.CreateContractors(CreateContractors(0));
                }

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

    }
}
