﻿using ProjectRepairWork.Repositories;
using ProjectRepairWork.Entities;
using ProjectRepairWork.Repositories.Implementation;
using System.Windows.Forms;
using ProjectRepairWork.Entities.Enums;

namespace ProjectRepairWork.Forms
{
    public partial class FormPremise : Form
    {
        private readonly IPremisesRepository _premisesRepository;
        private int? _premisesId;

        public int Id
        {
            set
            {
                try
                {
                    var premises = _premisesRepository.ReadPremisesById(value);
                    if (premises == null)
                    {
                        throw new InvalidDataException(nameof(premises));
                    }
                    textBoxClientName.Text = premises.ClientName;
                    textBoxAddress.Text = premises.Address;
                    numericUpDownArea.Value = (decimal)premises.Area;
                    dateTimePickerStart.Value = DateTime.Now;
                    dateTimePickerEnd.Value = DateTime.Now;
                    comboBoxPremisesType.SelectedItem = premises.PremisesType;
                    _premisesId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormPremise(IPremisesRepository premisesRepository)
        {
            InitializeComponent();
            _premisesRepository = premisesRepository ?? throw new ArgumentNullException(nameof(premisesRepository));

            comboBoxPremisesType.DataSource = Enum.GetValues(typeof(PremisesType));
        }

        private void Save_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxClientName.Text) ||
                    string.IsNullOrWhiteSpace(textBoxAddress.Text) || 
                        comboBoxPremisesType.SelectedIndex < 1)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_premisesId.HasValue)
                {
                    _premisesRepository.UpdatePremises(CreatePremises(_premisesId.Value));
                }
                else
                {
                    _premisesRepository.CreatePremises(CreatePremises(0));
                }

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void Cancel_Click(object sender, EventArgs e) => Close();

        private Premises CreatePremises(int id) => Premises.CreatEntity(
       id,
       textBoxClientName.Text,
       textBoxAddress.Text,
       Convert.ToInt32(numericUpDownArea.Value),
       dateTimePickerStart.Value, dateTimePickerStart.Value, (PremisesType)comboBoxPremisesType.SelectedItem!);


    }
}
