﻿using ProjectRepairWork.Repositories;
using ProjectRepairWork.Entities;
using ProjectRepairWork.Repositories.Implementation;
using System.Windows.Forms;
using ProjectRepairWork.Entities.Enums;

namespace ProjectRepairWork.Forms
{
    public partial class FormRepair : Form
    {
        private readonly IRepairRepository _repairRepository;
     
        public FormRepair(IRepairRepository repairRepository, IContractorsRepository contractorsRepository, ICostRepository costRepository, IPremisesRepository premisesRepository, IWorksRepository worksRepository)
        {
            InitializeComponent();
            _repairRepository = repairRepository ?? throw new ArgumentNullException(nameof(repairRepository));



            comboBoxContractors.DataSource = contractorsRepository.ReadContractors();
            comboBoxContractors.DisplayMember = "CompanyName";
            comboBoxContractors.ValueMember = "Id";

            comboBoxPremises.DataSource = premisesRepository.ReadPremises();
            comboBoxPremises.DisplayMember = "Name";
            comboBoxPremises.ValueMember = "Id";

            ColumnWork.DataSource = worksRepository.ReadWorks();
            ColumnWork.DisplayMember = "Name";
            ColumnWork.ValueMember = "Id";



        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (dataGridViewWorks.RowCount < 1|| comboBoxContractors.SelectedIndex < 0 ||
                    comboBoxPremises.SelectedIndex < 0)

                {
                    throw new Exception("Имеются незаполненные поля");
                }

                _repairRepository.CraeteRepair(Repair.CreatOpertions(0,
                    (int)comboBoxContractors.SelectedValue!,
                    (int)comboBoxPremises.SelectedValue!, CreateRepairFromDataGrid()));

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e) => Close();

        private List<RepairRepair> CreateRepairFromDataGrid()
        {
            var list = new List<RepairRepair>();
            foreach(DataGridViewRow row in dataGridViewWorks.Rows)
            {
                if (row.Cells["ColumnWork"].Value == null ||
                row.Cells["ColumnCount"].Value == null)
                {
                    continue;
                }
                list.Add(RepairRepair.CreatElement(0,
                    Convert.ToInt32(row.Cells["ColumnWork"].Value),
                    Convert.ToInt32(row.Cells["ColumnCount"].Value)));
            }
            return list;
        }
    }
}