﻿using ProjectRepairWork.Repositories;
using ProjectRepairWork.Entities;
using ProjectRepairWork.Repositories.Implementation;
using System.Windows.Forms;
using ProjectRepairWork.Entities.Enums;

namespace ProjectRepairWork.Forms
{
    public partial class FormWork : Form
    {


        private readonly IWorksRepository _worksRepository;
        private int? _worksId;

        public int Id
        {
            set
            {
                try
                {
                    var works = _worksRepository.ReadWorksById(value);
                    if (works == null)
                    {
                        throw new InvalidDataException(nameof(works));
                    }
                    foreach (MaterialsName elem in Enum.GetValues(typeof(MaterialsName)))
                    {
                        if ((elem & works.MaterialsName) != 0)
                        {

                            checkedListBoxMaterialsName.SetItemChecked(checkedListBoxMaterialsName.Items.IndexOf(elem), true);
                        }
                    }
                    textBoxWorksName.Text = works.WorkName;
                    _worksId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormWork(IWorksRepository worksRepository)
        {
            InitializeComponent();
            _worksRepository = worksRepository ?? throw new ArgumentNullException(nameof(worksRepository));
            foreach(var elem in Enum.GetValues(typeof(MaterialsName)))
            {
                checkedListBoxMaterialsName.Items.Add(elem);
            }
        }
        private void Save_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxWorksName.Text) ||
                    checkedListBoxMaterialsName.CheckedItems.Count == 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_worksId.HasValue)
                {
                    _worksRepository.UpdateWorks(CreateWorks(_worksId.Value));
                }
                else
                {
                    _worksRepository.CreateWorks(CreateWorks(0));
                }

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void Cancel_Click(object sender, EventArgs e) => Close();

        private Works CreateWorks(int id)
        {
            MaterialsName materialsName = MaterialsName.None;
            foreach(var elem in checkedListBoxMaterialsName.CheckedItems)
            {
                materialsName |= (MaterialsName)elem;
            }

            return Works.CreatEntity(id, textBoxWorksName.Text, materialsName);
        }

    }
}
